@@ -6,4 +6,4 @@
 '''
 from .set_gpu import set_gpu
 from .kill import get_nvidia_processes, get_ps_processes, get_user_processes, kill_processes
-from .notice import send_wechat
\ No newline at end of file
+from .notice import send_wechat, get_time_diff
\ No newline at end of file
